@@ -17,7 +17,8 @@ from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.payments.models import PaymentMethod
 from tinymce.widgets import TinyMCE
 from tendenci.core.perms.forms import TendenciBaseForm
-from captcha.fields import CaptchaField
+#from captcha.fields import CaptchaField
+from simplemathcaptcha.fields import MathCaptchaField
 from tendenci.apps.user_groups.models import Group
 from tendenci.core.base.utils import get_template_list
 from tendenci.core.base.fields import EmailVerificationField
@@ -144,7 +145,7 @@ class FormForForm(forms.ModelForm):
                 )
         
         if not self.user.is_authenticated() and get_setting('site', 'global', 'captcha'): # add captcha if not logged in
-            self.fields['captcha'] = CaptchaField(label=_('Type the code below'))
+            self.fields['captcha'] = MathCaptchaField(label=_('Type the code below'))
 
 
     def clean_pricing_option(self):
